@@ -28,7 +28,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 	match_date_and_time
 );
 
-$VERSION = '1.00_02';
+$VERSION = '1.01';
 
 sub date_and_time {
 	my $fmt = shift;
@@ -148,7 +148,7 @@ passed in to validate your date against. It understands the following symbols:
 	p	AM|PM
 
 Other parts of the string become part of the regular expression, so you can
-do perlish things like this to create mor complex expressions:
+do perlish things like this to create more complex expressions:
 
 	'MM?/DD?/YYYY|YYYY-MM?-DD?'
 
@@ -167,20 +167,27 @@ This older, more awkward interface is supported:
 		},
 	}
 
-=head1 TODO 
-
-Find a way to make standard formats available.  For example, having a format
-that you know PostgreSQL will accept as a valid. 
-
 =head1 SEE ALSO
 
-L<Data::FormValidator>, L<DateTime::Format::Pg>, L<DateTime::Format::MySQL>, L<DateTime::Format::Mail>
+=over 
+
+=item o
+
+L<Data::FormValidator>
+
+=item o 
+
+L<Data::FormValidator::Constraints::DateTime>  - This alternative features
+returning dates as DateTime objects and validating against the date formats
+required for the MySQL and PostgreSQL databases. 
+
+=back 
 
 =head1 AUTHOR
 
 Mark Stosberg, E<lt>mark@summersault.comE<gt>
 
-With magic code by Jan Krynicky. 
+Featuring clever code by Jan Krynicky. 
 
 =head1 COPYRIGHT AND LICENSE
 
